@@ -19,8 +19,8 @@ fi
 GROUPLIST=$($RATPOISON -c groups)
 SED_GET_NUM='s/^\([0-9]*\).*/\1/'
 
-FIRSTGROUPNUM=$(echo "$GROUPLIST"|head -1|sed -e "$SED_GET_NUM")
-LASTGROUP=$(echo "$GROUPLIST"|tail -1)
+FIRSTGROUPNUM=$(echo "$GROUPLIST"|head -n 1|sed -e "$SED_GET_NUM")
+LASTGROUP=$(echo "$GROUPLIST"|tail -n 1)
 CURRENTGROUPNUM=$(echo "$GROUPLIST"|grep '^[0-9]*\*'|sed -e "$SED_GET_NUM")
 
 $RATPOISON -c "gselect $FIRSTGROUPNUM"
